summaryrefslogtreecommitdiff
path: root/src/exchange/taler-exchange-httpd_db.h
diff options
context:
space:
mode:
authorFlorian Dold <florian.dold@gmail.com>2017-05-29 01:15:41 +0200
committerFlorian Dold <florian.dold@gmail.com>2017-05-29 01:15:41 +0200
commit85350ced32108f2ec69fbf62e0a7c3b256840fb1 (patch)
treeca8370f99feae0fb55dad2b5b13f0175e242fdcd /src/exchange/taler-exchange-httpd_db.h
parent5d58316d884e660ff9a83a6e7a4bd34ae4c8e734 (diff)
downloadexchange-85350ced32108f2ec69fbf62e0a7c3b256840fb1.tar.gz
exchange-85350ced32108f2ec69fbf62e0a7c3b256840fb1.tar.bz2
exchange-85350ced32108f2ec69fbf62e0a7c3b256840fb1.zip
rename proposal_data to contract_terms (see #4879)
Diffstat (limited to 'src/exchange/taler-exchange-httpd_db.h')
-rw-r--r--src/exchange/taler-exchange-httpd_db.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/exchange/taler-exchange-httpd_db.h b/src/exchange/taler-exchange-httpd_db.h
index 4d894cfb9..55faafa06 100644
--- a/src/exchange/taler-exchange-httpd_db.h
+++ b/src/exchange/taler-exchange-httpd_db.h
@@ -222,7 +222,7 @@ TEH_DB_execute_track_transfer (struct MHD_Connection *connection,
* associated with the given deposit.
*
* @param connection the MHD connection to handle
* @param h_proposal_data hash of the contract
* @param h_wire hash of the wire details
* @param coin_pub public key of the coin to link
* @param merchant_pub public key of the merchant
@@ -230,7 +230,7 @@ TEH_DB_execute_track_transfer (struct MHD_Connection *connection,
*/
int
TEH_DB_execute_track_transaction (struct MHD_Connection *connection,
- const struct GNUNET_HashCode *h_proposal_data,
+ const struct GNUNET_HashCode *h_contract_terms,
const struct GNUNET_HashCode *h_wire,
const struct TALER_CoinSpendPublicKeyP *coin_pub,
const struct TALER_MerchantPublicKeyP *merchant_pub);
@@ -222,7 +222,7 @@ TEH_DB_execute_track_transfer (struct MHD_Connection *connection,
*
* @param connection the MHD connection to handle
- * @param h_proposal_data hash of the contract
+ * @param h_contract_terms hash of the contract
* @param h_wire hash of the wire details
* @param coin_pub public key of the coin to link